email

package
v0.0.0-...-4c5e68c Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 12, 2026 License: MIT Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type ConfirmationMessage

type ConfirmationMessage struct {
	Email        string
	Repository   string
	ConfirmToken string
	ConfirmURL   string
}

ConfirmationMessage carries the data needed to send a confirmation email.

type ReleaseMessage

type ReleaseMessage struct {
	Email          string
	Repository     string
	Tag            string
	UnsubscribeURL string
}

ReleaseMessage carries the data needed to send a release notification email.

type SMTPConfig

type SMTPConfig struct {
	Host     string
	Port     int
	From     string
	Username string
	Password string
}

SMTPConfig defines SMTP transport settings.

type SMTPSender

type SMTPSender struct {
	// contains filtered or unexported fields
}

func NewSMTPSender

func NewSMTPSender(log *slog.Logger, cfg SMTPConfig) *SMTPSender

func (*SMTPSender) SendConfirmation

func (s *SMTPSender) SendConfirmation(ctx context.Context, message ConfirmationMessage) error

func (*SMTPSender) SendRelease

func (s *SMTPSender) SendRelease(ctx context.Context, message ReleaseMessage) error

Jump to