Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ConfirmationMessage ¶
type ConfirmationMessage struct {
Email string
Repository string
ConfirmToken string
ConfirmURL string
}
ConfirmationMessage carries the data needed to send a confirmation email.
type ReleaseMessage ¶
ReleaseMessage carries the data needed to send a release notification email.
type SMTPConfig ¶
SMTPConfig defines SMTP transport settings.
type SMTPSender ¶
type SMTPSender struct {
// contains filtered or unexported fields
}
func NewSMTPSender ¶
func NewSMTPSender(log *slog.Logger, cfg SMTPConfig) *SMTPSender
func (*SMTPSender) SendConfirmation ¶
func (s *SMTPSender) SendConfirmation(ctx context.Context, message ConfirmationMessage) error
func (*SMTPSender) SendRelease ¶
func (s *SMTPSender) SendRelease(ctx context.Context, message ReleaseMessage) error
Click to show internal directories.
Click to hide internal directories.